window.Gleam.initSearch([{"doc":"hardcache","title":"hardcache","content":"# hardcache\n\n[![Package Version](https://img.shields.io/hexpm/v/hardcache)](https://hex.pm/packages/hardcache)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/hardcache/)\n\nHardcache is a Gleam module that provides primitives for caching key-value pairs in files and using files as caches.\n\n## Examples\n\n```gleam\nimport hardcache\n\nimport gleam/float\nimport gleam/option\n\npub fn main() {\n  let cache = hardcache.new(&quot;./expensive&quot;, True)\n  case hardcache.try_get(cache, &quot;expensive_calculation&quot;) {\n    Ok(option.None) -&gt; {\n      let _ =\n        hardcache.try_set(cache, &quot;expensive_calculation&quot;, float.to_string(0.1 +. 0.2))\n    }\n    _ -&gt; Nil\n  }\n}\n```\n\n## Installation\n\nIf available on the Hex package manager, you can add **hardcache** to your project by running the command below:\n\n```sh\ngleam add hardcache\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/hardcache&gt;.\n\n## Development\n\n```sh\ngleam test # Run the tests\n```\n","url":"index.html"},{"doc":"hardcache","title":"Cache","content":"pub type Cache {\n  Cache(\n    file_path: String,\n    entries: List(#(String, String)),\n    auto_update: Bool,\n  )\n}\n\nCache(\n  file_path: String,\n  entries: List(#(String, String)),\n  auto_update: Bool,\n)\n\n\nSynonyms:\nhardcache.Cache\nhardcache Cache","url":"hardcache.html#Cache"},{"doc":"hardcache","title":"CacheError","content":"pub type CacheError {\n  CacheError(String)\n  FileError(file_error.FileError)\n  ReadStreamError(read_stream_error.ReadStreamError)\n}\n\nCacheError(String)\n\n\nFileError(file_error.FileError)\n\n\nReadStreamError(read_stream_error.ReadStreamError)\n\n\nSynonyms:\nhardcache.CacheError\nhardcache CacheError","url":"hardcache.html#CacheError"},{"doc":"hardcache","title":"auto_update","content":"pub fn auto_update(cache: Cache) -&gt; Cache\n Sets the auto_update field of the cache to True.\n \n ## Examples\n \n \n let cache = hardcache.new(&quot;./example.txt&quot;, False)\n let cache = case cache {\n   Ok(cache) -&gt; Ok(hardcache.auto_update(cache))\n   Error(e) -&gt; Error(e)\n }\n \n \nSynonyms:\nhardcache.auto_update\nhardcache auto_update","url":"hardcache.html#auto_update"},{"doc":"hardcache","title":"defaults","content":"pub fn defaults(\n  in orig: Cache,\n  defaults entries: List(#(String, String)),\n) -&gt; Result(Cache, CacheError)\n Sets a key-value pair in the list if it is not already set. \n \n ## Examples\n \n \n let cache = case hardcache.new(&quot;./example.txt&quot;, True) {\n   Ok(cache) -&gt; hardcache.defaults(cache, [#(&quot;msg&quot;, &quot;Hello!&quot;)])\n   err -&gt; err\n }\n \n \nSynonyms:\nhardcache.defaults\nhardcache defaults","url":"hardcache.html#defaults"},{"doc":"hardcache","title":"get","content":"pub fn get(from cache: Cache, key key: String) -&gt; Option(String)\n Gets the value associated with a key in the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n let a = case cache {\n   Ok(cache) -&gt;\n     cache\n     |&gt; hardcache.get(&quot;a&quot;)\n   Error(_) -&gt; option.None\n }\n \n \nSynonyms:\nhardcache.get\nhardcache get","url":"hardcache.html#get"},{"doc":"hardcache","title":"new","content":"pub fn new(\n  path file_path: String,\n  auto_update auto_update: Bool,\n) -&gt; Result(Cache, CacheError)\n Creates a new cache by reading from the specified file path.\n \n ## Examples\n \n \n let cache = hardcache.new(&quot;./example.txt&quot;, True)\n \n \nSynonyms:\nhardcache.new\nhardcache new","url":"hardcache.html#new"},{"doc":"hardcache","title":"parse_entries","content":"pub fn parse_entries(string: String) -&gt; List(#(String, String))\n Parses a string into key-value pairs.\n \n ## Example\n \n \n hardcache.parse_entries(&quot;!key=value\\n&quot;)\n // -&gt; [#(&quot;key&quot;, &quot;value&quot;)]\n \n \nSynonyms:\nhardcache.parse_entries\nhardcache parse_entries","url":"hardcache.html#parse_entries"},{"doc":"hardcache","title":"remove","content":"pub fn remove(\n  from orig: Cache,\n  key key: String,\n) -&gt; Result(Cache, CacheError)\n Removes a key-value pair from the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n // -&gt; Ok(Cache(&quot;./example.txt&quot;, &quot;!a=A\\n&quot;, True))\n let cache = case cache {\n   Ok(cache) -&gt;\n     cache\n     |&gt; hardcache.remove(&quot;a&quot;)\n   Error(e) -&gt; Error(e)\n }\n // -&gt; Ok(Cache(&quot;./example.txt&quot;, &quot;&quot;, True))\n \n \nSynonyms:\nhardcache.remove\nhardcache remove","url":"hardcache.html#remove"},{"doc":"hardcache","title":"set","content":"pub fn set(\n  in orig: Cache,\n  key key: String,\n  value value: String,\n) -&gt; Result(Cache, CacheError)\n Sets a key-value pair in the cache.\n \n ## Examples\n \n \n let cache = hardcache.new(&quot;./example.txt&quot;, True)\n let cache = case cache {\n   Ok(cache) -&gt;\n     cache\n     |&gt; hardcache.set(&quot;a&quot;, &quot;A&quot;)\n   Error(e) -&gt; Error(e)\n }\n \n \nSynonyms:\nhardcache.set\nhardcache set","url":"hardcache.html#set"},{"doc":"hardcache","title":"set_many","content":"pub fn set_many(\n  in orig: Cache,\n  entries entries: List(#(String, String)),\n) -&gt; Result(Cache, CacheError)\n Sets multiple key-value pairs in the cache.\n \n ## Examples\n \n \n let cache = hardcache.new(&quot;./example.txt&quot;, True)\n let cache = case cache {\n   Ok(cache) -&gt;\n     cache\n     |&gt; hardcache.set_many([#(&quot;a&quot;, &quot;A&quot;), #(&quot;b&quot;, &quot;B&quot;)])\n   Error(e) -&gt; Error(e)\n }\n \n \nSynonyms:\nhardcache.set_many\nhardcache set_many","url":"hardcache.html#set_many"},{"doc":"hardcache","title":"stringify_entries","content":"pub fn stringify_entries(\n  entries: List(#(String, String)),\n) -&gt; String\n Converts key-value pairs to a string.\n \n ## Example\n \n \n hardcache.stringify_entries([#(&quot;key&quot;, &quot;value&quot;)])\n // -&gt; &quot;!key=value\\n&quot;\n \n \nSynonyms:\nhardcache.stringify_entries\nhardcache stringify_entries","url":"hardcache.html#stringify_entries"},{"doc":"hardcache","title":"try_defaults","content":"pub fn try_defaults(\n  in orig: Result(Cache, CacheError),\n  defaults entries: List(#(String, String)),\n) -&gt; Result(Cache, CacheError)\n Sets a key-value pair in the list if it is not already set. \n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_defaults(cache, [#(&quot;msg&quot;, &quot;Hello!&quot;)])\n \n \nSynonyms:\nhardcache.try_defaults\nhardcache try_defaults","url":"hardcache.html#try_defaults"},{"doc":"hardcache","title":"try_get","content":"pub fn try_get(\n  from orig: Result(Cache, CacheError),\n  key key: String,\n) -&gt; Result(Option(String), CacheError)\n Sets multiple key-value pairs in the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n let a =\n   cache\n   |&gt; hardcache.try_get(&quot;a&quot;)\n \n \nSynonyms:\nhardcache.try_get\nhardcache try_get","url":"hardcache.html#try_get"},{"doc":"hardcache","title":"try_remove","content":"pub fn try_remove(\n  from orig: Result(Cache, CacheError),\n  key key: String,\n) -&gt; Result(Cache, CacheError)\n Sets a key-value pair in the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n // -&gt; Ok(Cache(&quot;./example.txt&quot;, &quot;!a=A\\n&quot;, True))\n let cache =\n   cache\n   |&gt; hardcache.try_remove(&quot;a&quot;)\n // -&gt; Ok(Cache(&quot;./example.txt&quot;, &quot;&quot;, True))\n \n \nSynonyms:\nhardcache.try_remove\nhardcache try_remove","url":"hardcache.html#try_remove"},{"doc":"hardcache","title":"try_set","content":"pub fn try_set(\n  in orig: Result(Cache, CacheError),\n  key key: String,\n  value value: String,\n) -&gt; Result(Cache, CacheError)\n Sets a key-value pair in the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n \n \nSynonyms:\nhardcache.try_set\nhardcache try_set","url":"hardcache.html#try_set"},{"doc":"hardcache","title":"try_set_many","content":"pub fn try_set_many(\n  in orig: Result(Cache, CacheError),\n  entries entries: List(#(String, String)),\n) -&gt; Result(Cache, CacheError)\n Sets multiple key-value pairs in the cache.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, True)\n   |&gt; hardcache.try_set_many([#(&quot;a&quot;, &quot;A&quot;), #(&quot;b&quot;, &quot;B&quot;)])\n \n \nSynonyms:\nhardcache.try_set_many\nhardcache try_set_many","url":"hardcache.html#try_set_many"},{"doc":"hardcache","title":"try_update","content":"pub fn try_update(\n  cache: Result(Cache, CacheError),\n) -&gt; Result(Cache, CacheError)\n Updates the cache file with the current cache content.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, False)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n   |&gt; hardcache.try_set(&quot;b&quot;, &quot;B&quot;)\n   |&gt; hardcache.try_set_many([#(&quot;c&quot;, &quot;C&quot;)])\n   |&gt; hardcache.try_update\n \n \nSynonyms:\nhardcache.try_update\nhardcache try_update","url":"hardcache.html#try_update"},{"doc":"hardcache","title":"update","content":"pub fn update(cache: Cache) -&gt; Result(Cache, CacheError)\n Updates the cache file with the current cache content.\n \n ## Examples\n \n \n let cache =\n   hardcache.new(&quot;./example.txt&quot;, False)\n   |&gt; hardcache.try_set(&quot;a&quot;, &quot;A&quot;)\n   |&gt; hardcache.try_set(&quot;b&quot;, &quot;B&quot;)\n   |&gt; hardcache.try_set_many([#(&quot;c&quot;, &quot;C&quot;)])\n \n let cache = case cache {\n   Ok(cache) -&gt; hardcache.update(cache)\n   Error(e) -&gt; Error(e)\n }\n \n \nSynonyms:\nhardcache.update\nhardcache update","url":"hardcache.html#update"},{"doc":"hardcache","title":"hardcache","content":"","url":"hardcache.html"}]);